@@ -112,9 +112,9 @@ DisplayGallery <- function(...,
   offsets = input[["offsets"]]
   param = input[["param"]]
   if(length(offsets) == 0) {
-    fileName = input[["fileName"]]
+    fileName = enc2native(input[["fileName"]])
   } else {
-    fileName = attr(offsets, "fileName_image")
+    fileName = enc2native(attr(offsets, "fileName_image"))
   }
 
   # check mandatory param
@@ -205,7 +205,8 @@ DisplayGallery <- function(...,
     param = input$param
     param$export = "base64"
     param$mode = mode
- }
+  }
+  param$fileName_image = enc2native(param$fileName_image)
   fileName = param$fileName_image
   title_progress = basename(fileName)
   
@@ -292,7 +293,6 @@ DisplayGallery <- function(...,
   } else {
     ans = ans[[1]]
   }
-
   # change layout
   if(missing(layout)) layout = channel_id
   layout = as.character(layout)
