@@ -130,9 +130,9 @@ ExportToGallery <- function(...,
   offsets = input[["offsets"]]
   param = input[["param"]]
   if(length(offsets) == 0) {
-    fileName = input[["fileName"]]
+    fileName = enc2native(input[["fileName"]])
   } else {
-    fileName = attr(offsets, "fileName_image")
+    fileName = enc2native(attr(offsets, "fileName_image"))
   }
   
   # check mandatory param
@@ -225,6 +225,7 @@ ExportToGallery <- function(...,
     param$export = "matrix"
     param$mode = "rgb"
   }
+  param$fileName_image = enc2native(param$fileName_image)
   fileName = param$fileName_image
   title_progress = basename(fileName)
   file_extension = getFileExt(fileName)
