@@ -58,7 +58,11 @@ addText <- function(image, text, color, xoff = 0, yoff = 0, corner = "TL") {
   txt_msk = texttomatrix(text)
   dt = dim(txt_msk)
   if((dt[1] + yoff > di[1]) | dt[2] + xoff > di[2]) {
-    txt_msk = cpp_resize(mat = txt_msk, new_height = di[2] - xoff, new_width = di[1] - yoff, add_noise = FALSE, bg = 0, sd= 0)
+    new_h = dt[1]
+    new_w = dt[2]
+    if(dt[1] + yoff > di[1]) new_h = di[1] - yoff
+    if(dt[2] + xoff > di[2]) new_w = di[2] - xoff
+    txt_msk = cpp_resize(mat = txt_msk, new_height = new_h, new_width = new_w, add_noise = FALSE, bg = 0, sd= 0)
   }
   
   # modify xoff, yoff according to corner anchorage
