@@ -38,8 +38,8 @@
 #' @param lightcolor lightcolor of the region. See \code{\link{paletteIFC}} for allowed colors.
 #' @param ismarker Default is 'false'. Allowed are 'true' or 'false'. Used for compatibility with amnis file but role remains unknown.
 #' @param doesnotoverride Default is 'false'. Allowed are 'true' or 'false'. Used for compatibility with amnis file but role remains unknown.
-#' @param xlogrange determines hyper parameter of smoothLinLog transformation for x-axis. Default is "P" for no transformation.
-#' @param ylogrange determines hyper parameter of smoothLinLog transformation for y-axis. Default is "P" for no transformation.
+#' @param xlogrange determines transformation instruction for x-axis. Default is "P" for no transformation.
+#' @param ylogrange determines transformation instruction for y-axis. Default is "P" for no transformation.
 #' @param x vector of x vertices values.
 #' @param y vector of y vertices values.
 #' @param ... Other arguments to be passed.
@@ -56,18 +56,18 @@ buildRegion <- function(type, label, cx, cy, color, lightcolor, ismarker="false"
   doesnotoverride = tolower(doesnotoverride); assert(doesnotoverride, len=1, alw=c("false","true"))
   if(missing(xlogrange)) stop("'xlogrange' can't be missing")
   if(missing(ylogrange)) stop("'ylogrange' can't be missing")
-  xlogrange = as.character(xlogrange)
-  ylogrange = as.character(ylogrange)
+  xlogrange = as.character(xlogrange); assert(xlogrange, len=1)
+  ylogrange = as.character(ylogrange); assert(ylogrange, len=1)
   if(xlogrange != "P") {
-    tmp = as.integer(xlogrange)
-    if(is.na(tmp)) stop("'xlogrange' should be coercible to positive integer")
-    if(tmp<0) stop("'xlogrange' should be coercible to positive integer")
+    tmp = suppressWarnings(as.numeric(xlogrange))
+    if(is.na(tmp)) stop("'xlogrange' should be either \"P\" or coercible to a positive numeric")
+    if(tmp<0) stop("'xlogrange' should be either \"P\" or coercible to a positive numeric")
     xlogrange = as.character(tmp)
   }
   if(ylogrange != "P") {
-    tmp = as.integer(ylogrange)
-    if(is.na(tmp)) stop("'ylogrange' should be coercible to positive integer")
-    if(tmp<0) stop("'ylogrange' should be coercible to positive integer")
+    tmp = suppressWarnings(as.numeric(ylogrange))
+    if(is.na(tmp)) stop("'ylogrange' should be either \"P\" or coercible to a positive numeric")
+    if(tmp<0) stop("'ylogrange' should be either \"P\" or coercible to a positive numeric")
     ylogrange = as.character(tmp)
   }
   if(missing(color)) {
@@ -101,28 +101,36 @@ buildRegion <- function(type, label, cx, cy, color, lightcolor, ismarker="false"
   
   if(missing(x)) stop("'x' can't be missing")
   if(missing(y)) stop("'y' can't be missing")
-  x = as.numeric(x)
-  y = as.numeric(y)
+  x = suppressWarnings(as.numeric(x))
+  y = suppressWarnings(as.numeric(y))
   x = x[is.finite(x)]
   y = y[is.finite(y)]
   if(type=="poly") {
     if(length(x) != length(y)) stop("'x' and 'y' should be numeric vectors of equal length with finite values")
     if(length(x)<2) stop("type='poly' and number of vertices is smaller than 2")
-    if(missing(cx) | missing(cy)) {
+    if(missing(cx) || missing(cy)) {
       # cent = cpp_poly_centroid(cbind(x,y)) # TODO # for future use
       # if(missing(cx)) cx= cent[1]
       # if(missing(cy)) cy= cent[2]
-      if(missing(cx)) cx= mean(x)
-      if(missing(cy)) cy= mean(y)
+      if(missing(cx)) cx=mean(x)
+      if(missing(cy)) cy=mean(y)
     }
   } else {
     if(length(x) != 2) stop(paste0("'x' should be a length 2 numeric vector with finite values when type is '",type,"'"))
     if(length(y) != 2) stop(paste0("'y' should be a length 2 numeric vector with finite values when type is '",type,"'"))
-    if(type=="line" & y[1]!=y[2]) stop("'y' values should be identical when type is 'line")
-    if(missing(cx) | missing(cy)) {
-      if(missing(cx)) cx= mean(x)
-      if(missing(cy)) cy= mean(y)
+    if(type=="line" && y[1]!=y[2]) stop("'y' values should be identical when type is 'line")
+    if(missing(cx) || missing(cy)) {
+      if(missing(cx)) cx=mean(x)
+      if(missing(cy)) cy=mean(y)
     }
   }
-  return(list("type"=type, "label"=label, "cx"=cx, "cy"=cy, "color"=color, "lightcolor"=lightcolor, "ismarker"=ismarker, "doesnotoverride"=doesnotoverride, "xlogrange"=xlogrange, "ylogrange"=ylogrange, "x"=x, "y"=y))
+  Xtrans = dots$xtrans; parseTrans(Xtrans)
+  Ytrans = dots$ytrans; parseTrans(Ytrans)
+  return(list("type"=type, "label"=label,
+              "cx"=suppressWarnings(as.numeric(cx)), "cy"=suppressWarnings(as.numeric(cy)),
+              "color"=color, "lightcolor"=lightcolor,
+              "ismarker"=ismarker, "doesnotoverride"=doesnotoverride,
+              "xlogrange"=xlogrange, "ylogrange"=ylogrange,
+              "xtrans"=Xtrans, "ytrans"=Ytrans,
+              "x"=x, "y"=y))
 }
