@@ -29,11 +29,11 @@
 
 #' @title IFC_pops Computation
 #' @description
-#' Function used to compute `IFC_pops`\cr
+#' Function used to compute `IFC_pops` object\cr
 #' It requires pops, regions and features.
-#' @param pops list of populations.
-#' @param regions list of regions.
-#' @param features data.frame of features.
+#' @param pops list of populations that will be coerced by \code{\link{buildPopulation}}.
+#' @param regions an object of class `IFC_regions`, list of regions.
+#' @param features an object of class `IFC_features`, data.frame of features.
 #' @param pnt_in_poly_algorithm algorithm used to determine if object belongs to a polygon region or not. Default is 1.\cr
 #' Note that for the moment only 1(Trigonometry) is available.
 #' @param pnt_in_poly_epsilon epsilon to determine if object belongs to a polygon region or not. It only applies when algorithm is 1. Default is 1e-12.
@@ -42,10 +42,10 @@
 #' @param ... other arguments to be passed.
 #' @source For pnt_in_poly_algorithm, Trigonometry, is an adaptation of Jeremy VanDerWal's code \url{https://github.com/jjvanderwal/SDMTools}
 #' @return an object of class `IFC_pops`.
-#' @keywords internal
-popsCompute <- function(pops, regions, features, pnt_in_poly_algorithm = 1, 
-                        pnt_in_poly_epsilon = 1e-12, display_progress = TRUE, 
-                        title_progress = "", ...) {
+#' @export
+popsCompute <- function(pops, regions, features,
+                        pnt_in_poly_algorithm = 1, pnt_in_poly_epsilon = 1e-12,
+                        display_progress = TRUE, title_progress = "", ...) {
   dots = list(...)
   # coerce pops to buildPopulation() checking
   pops = lapply(pops, FUN=function(p) do.call(what = "buildPopulation", args = p))
